A pairwise phylogenetic distance matrices was created
using functions in the ape package. 100 phylogenetic trees were
downloaded from Birdtree.org and used to calculate mean pairwise distance. The pairwise
distances were then scaled to range [0, 1]. The
entire workflow is shown in the Appendix S4 script.
1 | data("Bird.phy.distances")
|
A matrix object with 303 rows and 303 columns, where each cell lists the
scaled pairwise phylogenetic distance between species in the corresponding row and column.
Row and column orders match the column orders in the BBS.abundances
and BBS.occurrences datafiles
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.